docs.rs failed to build jlrs-ndarray-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
jlrs-ndarray-0.3.0
Borrow data from Julia arrays as ndarray's ArrayView and ArrayViewMut.
This crate defines a single trait, NdArray, that provides methods that return an immutable
or a mutable view of the array data and is implemented by Array and TypedArray from jlrs.
Example:
use *;
use NdArray;