[][src]Trait jlrs_ndarray::NdArray

pub trait NdArray<'borrow, T>: Sealed {
    pub fn array_view<'frame: 'borrow, F>(
        self,
        frame: &'borrow F
    ) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>>
    where
        F: Frame<'frame>,
        T: ValidLayout + Copy
;
pub fn array_view_mut<'frame: 'borrow, F>(
        self,
        frame: &'borrow mut F
    ) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>>
    where
        F: Frame<'frame>,
        T: ValidLayout + Copy
; }

Trait to borrow Julia arrays with inline data as ndarray's ArrayView and ArrayViewMut.

Required methods

pub fn array_view<'frame: 'borrow, F>(
    self,
    frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
    F: Frame<'frame>,
    T: ValidLayout + Copy
[src]

Borrow the data in the array as an ArrayView. Returns an error if the wrong type is provided or the data is not stored inline.

pub fn array_view_mut<'frame: 'borrow, F>(
    self,
    frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
    F: Frame<'frame>,
    T: ValidLayout + Copy
[src]

Mutably borrow the data in the array as an ArrayViewMut. Returns an error if the wrong type is provided or the data is not stored inline.

Loading content...

Implementations on Foreign Types

impl<'frame: 'borrow, 'data: 'borrow, 'borrow, T: ValidLayout + Copy> NdArray<'borrow, T> for Array<'frame, 'data>[src]

impl<'frame: 'borrow, 'data: 'borrow, 'borrow, T: ValidLayout + Copy> NdArray<'borrow, T> for TypedArray<'frame, 'data, T>[src]

Loading content...

Implementors

Loading content...