[−][src]Trait jlrs_ndarray::NdArray
Trait to borrow Julia arrays with inline data as ndarray's ArrayView and ArrayViewMut.
Required methods
fn array_view<'frame: 'borrow, F>(
self,
frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'frame>,
T: ValidLayout + Copy,
self,
frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'frame>,
T: ValidLayout + Copy,
Borrow the data in the array as an ArrayView. Returns an error if the wrong type is
provided or the data is not stored inline.
fn array_view_mut<'frame: 'borrow, F>(
self,
frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'frame>,
T: ValidLayout + Copy,
self,
frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'frame>,
T: ValidLayout + Copy,
Mutably borrow the data in the array as an ArrayViewMut. Returns an error if the wrong
type is provided or the data is not stored inline.
Implementations on Foreign Types
impl<'frame: 'borrow, 'data: 'borrow, 'borrow, T: ValidLayout + Copy> NdArray<'borrow, T> for Array<'frame, 'data>[src]
fn array_view<'fr: 'borrow, F>(
self,
frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout + Copy, [src]
self,
frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout + Copy,
fn array_view_mut<'fr: 'borrow, F>(
self,
frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout + Copy, [src]
self,
frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout + Copy,
impl<'frame: 'borrow, 'data: 'borrow, 'borrow, T: ValidLayout + Copy> NdArray<'borrow, T> for TypedArray<'frame, 'data, T>[src]
fn array_view<'fr: 'borrow, F>(
self,
frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout, [src]
self,
frame: &'borrow F
) -> JlrsResult<ArrayView<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout,
fn array_view_mut<'fr: 'borrow, F>(
self,
frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout, [src]
self,
frame: &'borrow mut F
) -> JlrsResult<ArrayViewMut<'borrow, T, Dim<IxDynImpl>>> where
F: Frame<'fr>,
T: ValidLayout,